--时间相关工具类
TimeTools = {}
TimeTools.__index = TimeTools
local timeLabel = nil


--[[
os.time返回的是从1970年x月x日到现在经过的秒数
os.date返回的是按照一定格式输出的日期字符串或table。

java time 是毫秒
lua的os.time是秒
c# time 是java time * 10000

> print(os.time())
1337060663
> print(os.date())
05/15/12 13:44:30

]]

--传入结束时间戳返回剩余时间戳
function TimeTools.GetSurplusTime(endTime)
    local surplusTime = endTime - os.time ()
	--print("endTime"..endTime.."surplusTime"..surplusTime.."os.time ()"..os.time ())
    return surplusTime
end

--传入结束时间戳返回剩余时间的 时分秒格式 参数是java时间
function TimeTools.GetSurplusTimeOfSFM(endTime)
    
    return TimeTools.FormatTimeOfSFM(TimeTools.GetSurplusTime(endTime))
end

--格式化时间 时:分:秒 以00:00:00格式 获取 lua 下os.time
--只能返回以 1970 1 1 8:00:00格式的 如果参数是0 返回的就是这个时间  
--如果针入秒为单位的时间想返回hh:mm:ss请调用TimeTools.FormatTimeOfSecond
function TimeTools.FormatTimeOfSFM (time)
	--print("FormatTimeOfSFM"..time)
    return os.date("%H:%M:%S",time)
end


--格式化时间 时:分:秒 以00:00:00格式 获取 lua 下os.time
function TimeTools.FormatJavaTimeOfSFM (javatime)
	local time = TimeTools.JavaTimeToOSTime(javatime)
    return os.date("%H:%M:%S",time)
end

--格式化时间 时:分:秒 以00:00:00格式 获取 lua 下os.time
function TimeTools.FormatJavaTimeOfSF (javatime)
	local time = TimeTools.JavaTimeToOSTime(javatime)
    return os.date("%H:%M",time)
end

--格式化时间 时:分:秒 00:01:00
function TimeTools.FormatTimeOfSecond (timeNum)

	local _seconds = timeNum % 60

	local _minutes = (timeNum - _seconds)/60 % 60
	--_minutes = TimeTools.GetPreciseDecimal(_minutes, 0)

	local _hour = (timeNum -_seconds - _minutes*60) / 60 / 60 
	--_hour = TimeTools.GetPreciseDecimal(_hour, 0)
	
	
	local _time = string.format("%02d:%02d:%02d",_hour,_minutes,_seconds)
    return _time
end
--传入秒数  返回当前秒数转换成的时分秒
function  TimeTools.FormatTimeOfSurplusTime(timeNum)
	
	local _hour = timeNum / 60 / 60
	--print("_hour".._hour)
	_hour = math.floor(_hour)
	--print("_hour---------".._hour.."timeNum"..timeNum)
	local _minutes = (timeNum-(_hour*3600))/ 60
	_minutes = math.floor(_minutes)
	--	print("_minutes---------".._minutes)

	local _seconds = timeNum-(_hour*3600)-(_minutes*60)
	_seconds =   math.floor(_seconds)
	--	print("_seconds---------".._seconds)
	local _time = string.format("%02d:%02d:%02d",_hour,_minutes,_seconds)
    return _time
end 
--格式化时间 时:分
function TimeTools.FormatTimeOfSF (time)
    return os.date("%H:%M",time)
end

--格式化时间 年:月:日
function TimeTools.FormatTimeOfNYR (javatime)
	local time = TimeTools.JavaTimeToOSTime(javatime)
    return os.date ("%Y年%m月%d日", time)
end

--格式化时间 年-月-日
function TimeTools.FormatTimeOfNYRY_M_D (javatime)
	local time = TimeTools.JavaTimeToOSTime(javatime)
    return os.date ("%Y-%m-%d", time)
end

--格式化时间 月：日
function TimeTools.FormatTimeOfYR (javatime)
	local time = TimeTools.JavaTimeToOSTime(javatime)
    return os.date ("%m月%d日", time)
end

--格式化时间 年:月:日:时:分:秒
function TimeTools.FormatTimeOfNYRSFM (javatime)
	local time = TimeTools.JavaTimeToOSTime(javatime)
    return os.date ("%Y-%m-%d %H:%M:%S", time)
end
--格式化时间 月：日：时：分
function TimeTools.FormatTimeOfMDHM(javatime)
	local time = TimeTools.JavaTimeToOSTime(javatime)
    return os.date ("%m月%d日 %H:%M", time)
end

--格式化时间 年:月:日:时
function TimeTools.FormatTimeOfNYRS (javatime)
	local time = TimeTools.JavaTimeToOSTime(javatime)
    return os.date ("%Y年%m月%d日 %H点", time)
end

-- boolen to string
function TimeTools.BooleanToString(bool)
	str = bool and "真" or "假"
	return str
end

-- number to inter
function TimeTools.NubmerToInter(_number)
	local number = _number - 0
	if number <= 0 then
		return math.ceil(number)
	end
	if math.ceil(number) == number then
		return number
	else
		return math.ceil(number) - 1
	end
end


-- 保留小数点自定义位数
function TimeTools.GetPreciseDecimal(num, n)

	return UnityTools.GetPreciseDecimal(num,n)
end

function PrintTime ()
    print(os.date ("%H:%M:%S", os.time() ))
end

--将服务器的时间（string形式的毫秒单位)转成 秒单位
function TimeTools.ChangeServerTimeToSec(serverTime)
    return string.sub(serverTime, 0, string.len(serverTime) - 3)
end

--将服务器时间转成os.time时间
function TimeTools.JavaTimeToOSTime(javaTime)
	local javaToLuaTime = javaTime/1000
    --print("java to lua time is "..javaToLuaTime);
    javaToLuaTime = UnityTools.GetPreciseDecimal(javaToLuaTime)

	--local javaToLuaTime = (javaTime-javaTime%1000)/1000
	--logError("javaToLuaTime")
	--logError(javaTime)
	--logError(javaToLuaTime)
	return javaToLuaTime
end

--将服务器时间转成os.time时间
function TimeTools.OSTimeToJavaTime(osTime)
	local javaTime = osTime*1000
    --print("java to lua time is "..javaToLuaTime);
    
	return javaTime
end

--获得当前时间的时分秒
function TimeTools.GetCurTimeSFM()
	return TimeTools.FormatTimeOfSFM(os.time())
end

--获得当前时间
function TimeTools.GetCurTime()
	return os.time()
end
--return TimeTools

--根据服务器给的utc时间戳，进行根据本地时区转化和比较等操作 用c#实现的********************************************

--根据服务器传的时间戳 返回string为本机时区的时间2019.3.23形式
function TimeTools.GetTimeStrByServer(timeStamp)
	return GzTimeManage.Instance:GetTimeStrByServer(timeStamp);
end
--根据服务器传的时间戳 返回string本机时区的时间   具体形式 由参数formatStr决定  如"yyyy-MM-dd  HH:mm:ss"
function TimeTools.GetTimeStrByServerForm(timeStamp,formatStr)
	return GzTimeManage.Instance:GetTimeStrByServerForm(timeStamp,formatStr);
end
--根据时间戳值返回本机时间 距离这个时间 剩余的时间(  大于一天显示天数 小于一天显示小时数，小于一小时 0)
function TimeTools.GetLeftTime(timeStamp)
	return GzTimeManage.Instance:GetLeftTime(timeStamp);
end
--根据时间戳 和当前时间做比较 返回是否已过期
function TimeTools.HaveOutOfDate(timeStamp)
	return GzTimeManage.Instance:haveOutOfDate(timeStamp);
end
--/** 获得当前日期 具体到日 用来存本地判断当天是不是第一次进游戏 返回值为string*/
function TimeTools.getCurDayStrig()
	return GzTimeManage.Instance:getCurDayStrig();
end
--*****************************************************
